CANSocket
A safe Linux SocketCAN async wrapper with minimal dependencies. Utilises
async-io to be cross compatible with many executors and implements embedded-can
traits.
Virtual CAN device for testing
Examples and integration tests require a virtual device vcan0 to be created.
sudo ip link add dev vcan0 type vcan
sudo ip link set up vcan0To skip the integration tests, pass the --lib flag to cargo.
cargo test --libStructs
- CanError
- Error frame details.
- Controller
Error - Controller error state.
- Frame
- CAN Bus frame.
- Protocol
Error Kind - Protocol error kind flags.
- Socket
- CAN Bus interface socket.
- Transceiver
Error - Transceiver error.
Enums
- Error
- Error type.
- Frame
Create Error - Frame creation error.
- Id
- A CAN Identifier (standard or extended).
- Protocol
Error Location - Protocol error location.
- Transceiver
Error Kind - Transceiver error type.